target: Add weak target specific function for mmc caps

Add default target specific function to populate the
capabilities of the mmc host.

Change-Id: Ic0428e39009a650da253927a8433d530772a363d
diff --git a/target/init.c b/target/init.c
index fc5c34a..78a7bad 100644
--- a/target/init.c
+++ b/target/init.c
@@ -119,8 +119,13 @@
 {
 }
 
-/* Default target specific function for mmc bus width */
-__WEAK int target_mmc_bus_width()
+/*
+ * Default target specific function to set the capabilities for the host
+ */
+__WEAK void target_mmc_caps(struct mmc_host *host)
 {
-	return MMC_BOOT_BUS_WIDTH_4_BIT;
+	host->caps.ddr_mode = 0;
+	host->caps.hs200_mode = 0;
+	host->caps.bus_width = MMC_BOOT_BUS_WIDTH_4_BIT;
+	host->caps.hs_clk_rate = MMC_CLK_50MHZ;
 }